// This file is part of Blue UNO. Please see UNOMain.java or http://blueuno.udd.be/ for
// license information. 
// Copyright (C) 2007 Niklas Udd
//
// This class handles bluetooth communication and implements the IConnector interface.

package be.udd.blueuno;

import java.util.Vector;
import javax.bluetooth.*;

public class BluetoothConnector implements IConnector {
	private L2CAPConnection connection;
	private Vector queue;
	private IConnectorNotifier notifier;

	public BluetoothConnector(L2CAPConnection connection) {
		this.connection = connection;
		queue = new Vector();
		notifier = null;
	}

	public void setNotifier(IConnectorNotifier notifier) {
		this.notifier = notifier;
	}

	public void send(String message) throws Exception {
		connection.send(message.getBytes());
	}

	public boolean hasReceived() {
		return (queue.size() > 0);
	}

	public String receive() {
		if(hasReceived()) {
			String message;
			synchronized(queue) {
				message = (String)queue.elementAt(0);
				queue.removeElementAt(0);
			}
			return message;
		} else {
			return null;
		}
	}

	public String receiveBlocking() throws Exception {
		byte[] data = new byte[connection.getReceiveMTU()];
		int length = connection.receive(data);
		
		return new String(data,0,length);
	}

	public void startReceiving() {
		try {
			while(true) {
				String message = receiveBlocking();
				synchronized(queue) {
					queue.addElement(message);
				}
				if(notifier != null)
					notifier.messageReceived();
			}
		} catch(Exception e) {}
	}

	public void close() throws Exception {
		connection.close();
	}
}