// This file is part of Blue UNO. Please see UNOMain.java or http://blueuno.udd.be/ for
// license information. 
// Copyright (C) 2007 Niklas Udd
//
// This class lets the user initialize the search for nearby bluetooth devices (in order
// to find a server to connect to).

package be.udd.blueuno;

import javax.microedition.lcdui.*;

public class ClientStarter implements IUNOState, CommandListener {
	private UNOMain controller;
	private Language language;
	private ServerFinder serverFinder;

	private Form form;
	private Command searchCommand;
	private Command cancelCommand;

	public ClientStarter(UNOMain controller, Language language) {
		this.controller = controller;
		this.language = language;
		serverFinder = new ServerFinder(controller, this);

		searchCommand = new Command(language.get("search"), Command.OK, 1);
		cancelCommand = new Command(language.get("cancel"), Command.CANCEL, 2);
		form = new Form(language.get("client_text"));
		form.append(language.get("client_more"));
		form.addCommand(searchCommand);
		form.addCommand(cancelCommand);
		form.setCommandListener(this);
	}

	public void commandAction(Command c, Displayable d) {
		if (c == searchCommand) {
			form.delete(form.size() - 1);
			form.append(language.get("client_started"));
			form.removeCommand(searchCommand);
			form.removeCommand(cancelCommand);
			serverFinder.findClients();
		} else if (c == cancelCommand) {
			controller.cancelServerClient();
		}
	}

	public void searchAborted() {
		form.delete(form.size() - 1);
		form.append(language.get("client_error"));
		form.addCommand(cancelCommand);
	}

	public void noDevicesFound() {
		form.delete(form.size() - 1);
		form.append(language.get("client_none"));
		form.addCommand(searchCommand);
		form.addCommand(cancelCommand);
	}

	public Displayable getDisplayable() {
		return form;
	}
}