// This file is part of Blue UNO. Please see UNOMain.java or http://blueuno.udd.be/ for
// license information. 
// Copyright (C) 2007 Niklas Udd
//
// This class implements the color chooser, which is used when the player wants to play
// a Choose Color card.

package be.udd.blueuno;

import javax.microedition.lcdui.*;

public class ColorChooser {
	private Language language;
	private boolean active;
	private int selectedColor;

	public ColorChooser(Language language) {
		this.language = language;
		inactivate();
	}

	public int getSelectedColor() {
		return selectedColor;
	}

	public void activate() {
		active = true;
	}

	public void inactivate() {
		active = false;
		selectedColor = 0;
	}

	public boolean isActive() {
		return active;
	}

	public void moveLeft() {
		selectedColor--;
		if(selectedColor < 0)
			selectedColor = 3;
	}

	public void moveRight() {
		selectedColor++;
		if(selectedColor > 3)
			selectedColor = 0;
	}

	public void paint(Graphics g, int x, int y, int width, int height1, int height2, int height3) {
		if(!isActive())
			return;

		g.setColor(0xffffff);
		g.fillRect(x + 20, (y + height1 + height2/2), width - 40, height3);
		g.setColor(0x000000);
		g.drawRect(x + 20, (y + height1 + height2/2), width - 40, height3);

		g.drawString(language.get("game_choose_color"), (x + width/2), (y + height1 + height2 - 5), (Graphics.BOTTOM|Graphics.HCENTER));

		int boxSize = 20;
		int spaceSize = (width - 40 - 4*boxSize)/5;

		if(spaceSize < 5) {
			boxSize = 10;
			spaceSize = (width - 40 - 4*boxSize)/5;
		}

		int xPos = 20 + spaceSize;
		int yPos = y + height1 + height2;

		for(int i = 0; i < 4; i++) {
			g.setColor(CardHandler.colorNumberToColor(i));
			g.fillRect(xPos, yPos, boxSize, boxSize);
			g.setColor(0x000000);
			g.drawRect(xPos, yPos, boxSize, boxSize);

			if(selectedColor == i) {
				g.setColor(0xff0000);
				g.drawRect(xPos - 2, yPos - 2, boxSize + 4, boxSize + 4);
			}

			xPos += boxSize + spaceSize;
		}
	}
}