// This file is part of Blue UNO. Please see UNOMain.java or http://blueuno.udd.be/ for
// license information. 
// Copyright (C) 2007 Niklas Udd
//
// This class is shown to the user after s/he has selected a server to connect to.

package be.udd.blueuno;

import javax.microedition.lcdui.*;

public class Connecting implements IUNOState, CommandListener {
	private UNOMain controller;
	private Language language;
	private BluetoothConnector connector;

	private Form form;
	private Command cancelCommand;

	public Connecting(UNOMain controller, Language language) {
		this.controller = controller;
		this.language = language;

		cancelCommand = new Command(language.get("cancel"), Command.CANCEL, 2);
		form = new Form(language.get("connecting_text"));
		form.append(language.get("connecting_more"));
		form.setCommandListener(this);
	}

	public void commandAction(Command c, Displayable d) {
		if (c == cancelCommand) {
			controller.cancelServerClient();
		}
	}

	public void connectorCreated(BluetoothConnector _connector) {
		this.connector = _connector;

		form.delete(form.size() - 1);
		form.append(language.get("connecting_done"));
		try {
			connector.receiveBlocking();

			(new Thread() { public void run() { connector.startReceiving(); } }).start();
			controller.connectionEstablished(connector);
		} catch(Exception e) {
			searchAborted();
		}
	}

	public void searchAborted() {
		form.delete(form.size() - 1);
		form.append(language.get("connecting_error"));
		form.addCommand(cancelCommand);
	}

	public void serverClosed() {
		form.delete(form.size() - 1);
		form.append(language.get("connecting_closed"));
		form.addCommand(cancelCommand);
	}

	public void clientDeprecated() {
		form.delete(form.size() - 1);
		form.append(language.get("connecting_deprecated"));
		form.addCommand(cancelCommand);
	}

	public Displayable getDisplayable() {
		return form;
	}
}