// This file is part of Blue UNO. Please see UNOMain.java or http://blueuno.udd.be/ for
// license information. 
// Copyright (C) 2007 Niklas Udd
//
// This class handles local communication (that is when the server and client is running
// on the same device) and implements the IConnector interface.

package be.udd.blueuno;

import java.util.Vector;

public class LocalConnector implements IConnector {
	private LocalConnector otherConnector;
	private Vector queue;
	private IConnectorNotifier notifier;

	public LocalConnector() {
		otherConnector = null;
		queue = new Vector();
		notifier = null;
	}

	public LocalConnector(LocalConnector otherConnector) {
		this.otherConnector = otherConnector;
		otherConnector.setOtherConnector(this);
		queue = new Vector();
		notifier = null;
	}

	public void setOtherConnector(LocalConnector otherConnector) {
		this.otherConnector = otherConnector;
	}

	public void setNotifier(IConnectorNotifier notifier) {
		this.notifier = notifier;
	}

	public void send(String message) {
		if(otherConnector != null)
			otherConnector.localReceive(message);
	}

	public boolean hasReceived() {
		return (queue.size() > 0);
	}

	public String receive() {
		if(hasReceived()) {
			String message;
			synchronized(queue) {
				message = (String)queue.elementAt(0);
				queue.removeElementAt(0);
			}
			return message;
		} else {
			return null;
		}
	}

	public void localReceive(String message) {
		synchronized(queue) {
			queue.addElement(message);
		}
		if(notifier != null)
			notifier.messageReceived();
	}

	public String receiveBlocking() {
		while(!hasReceived()) {
			try { Thread.sleep(200); } catch(Exception e) { }
		}
		return receive();
	}

	public void close() {}
}