// This file is part of Blue UNO. Please see UNOMain.java or http://blueuno.udd.be/ for
// license information. 
// Copyright (C) 2007 Niklas Udd
//
// This class handles messages that are shown to the user when the game is being played.
// These messages are fading and this class is responsible for handling that.

package be.udd.blueuno;

import javax.microedition.lcdui.*;
import java.util.Date;

public class MessageHandler {
	private GameScreen gameScreen;
	private Language language;

	private String message;
	private long messageUpdated;

	public MessageHandler(GameScreen gameScreen, Language language) {
		this.gameScreen = gameScreen;
		this.language = language;
		message = null;
	}

	public void setMessageByCode(String code) {
		setMessage(language.get(code));
	}

	public void setMessage(String message) {
		this.message = message;
		messageUpdated = (new Date()).getTime();

		// A new thread is started with the task of repainting the GameScreen in order to ensure
		// that the message is actually repainted often enough for the fading to be visible.
		(new Thread(){ public void run() {
			for(int i = 0; i < 10; i++) {
				try { Thread.sleep(500); } catch(Exception e) {}
				gameScreen.repaint();
			}
		} }).start();
	}

	public void handleShowMessage(String command) {
		String text;

		if(command.equals("error"))
			text = language.get("game_error");
		else if(command.equals("illegal"))
			text = language.get("game_illegal");
		else if(command.equals("notturn"))
			text = language.get("game_not_turn");
		else if(command.startsWith("uno"))
			text = command.substring(4) + language.get("game_says_uno");
		else if(command.startsWith("nouno"))
			text = command.substring(6) + language.get("game_forgot_uno");
		else if(command.startsWith("leave"))
			text = command.substring(6) + language.get("game_leaves");
		else if(command.startsWith("get")) {
			int lastSpace = 0;
			for(int i = 0; i < command.length(); i++) {
				if(command.charAt(i) == ' ')
					lastSpace = i;
			}
	
			String name = command.substring(4,lastSpace);
			String numCards = command.substring(lastSpace + 1);
			text = name + language.get("game_get_cards_middle") + numCards + language.get("game_get_cards_after");
		} else {
			text = "*" + command.substring(5);
		}
	
		setMessage(text);
	}

	public void paint(Graphics g, int x, int y, int width, int height1, int height2, int height3, int currentBackgroundColor) {
		if(message != null) {
			int maxGrayLevel = currentBackgroundColor & 0x0000ff;
			long nowMillis = (new Date()).getTime();
			long diff = nowMillis - messageUpdated;
		
			int grayLevel = (int)((maxGrayLevel * diff)/5000);
		
			if(grayLevel > maxGrayLevel) {
				message = null;
			} else {
				g.setColor(grayLevel, grayLevel, grayLevel);
				g.drawString(message, (x + width/2), (y + height1 + height2 + height3 + 2), (Graphics.TOP|Graphics.HCENTER));
			}
		}
	}
}