// This file is part of Blue UNO. Please see UNOMain.java or http://blueuno.udd.be/ for
// license information. 
// Copyright (C) 2007 Niklas Udd
//
// This class is responsible for reporting scores to the high score. It does so by
// implementing a (very) primitive XML-RPC client.

package be.udd.blueuno;

import javax.microedition.io.*;
import java.io.*;

public class ScoreReporter {
	private SendScreen screen;
	private String[] highScore;
	private String rank;

	public ScoreReporter(SendScreen screen) {
		this.screen = screen;
	}

	public void send(String name, String location, int points) {
		String body = "<?xml version=\"1.0\"?>\n" +
			"<methodCall>\n" +
			"  <methodName>reportScore</methodName>\n" +
			"  <params>\n" +
			"    <param>\n" +
			"      <value><string>" + name + "</string></value>\n" +
			"    </param>\n" +
			"    <param>\n" +
			"      <value><string>" + location + "</string></value>\n" +
			"    </param>\n" +
			"    <param>\n" + 
			"      <value><int>" + points + "</int></value>\n" +
			"    </param>\n" +
			"  </params>\n" +
			"</methodCall>";
		byte[] data = body.getBytes();
		String inText;

		try {
			HttpConnection connection = (HttpConnection) Connector.open("http://blueuno.udd.be/report_score.php");
			connection.setRequestMethod(HttpConnection.POST);
			connection.setRequestProperty("Content-type", "text/xml");

			OutputStream out = connection.openOutputStream();
			out.write(data);
			out.close();

			int ch;
			StringBuffer sb = new StringBuffer();
			InputStream in = connection.openInputStream();
        	        while ((ch = in.read()) != -1) {
                	    sb.append((char)ch);
	                }
			inText = sb.toString();
			in.close();

			processInput(inText);	

			connection.close();

			screen.sent();
		} catch(Exception e) {
			screen.failed();
		}
	}

	private void processInput(String inText) throws Exception {
		// Initialize high score array
		highScore = new String[10];
		for(int i = 0; i < highScore.length; i++)
			highScore[i] = null;

		// Fill high score array
		int pos = 0;
		int startIndex = 0;
		int stopIndex = 0;
		String separator = "<value><string>";
		String separator2 = "</string></value>";

		while((startIndex = inText.indexOf(separator, stopIndex)) > 0) {
			stopIndex = inText.indexOf(separator2, startIndex);

			if(stopIndex > 0) {
				if(pos < highScore.length)
					highScore[pos++] = inText.substring(startIndex + separator.length(), stopIndex);
			}
		}
		
		// Set rank
		separator = "<value><int>";
		separator2 = "</int></value>";
		startIndex = inText.indexOf(separator, 0);
		stopIndex = inText.indexOf(separator2, startIndex);
		rank = inText.substring(startIndex + separator.length(), stopIndex);
	}

	public String[] getHighScore() {
		return highScore;
	}

	public String getRank() {
		return rank;
	}
}