// This file is part of Blue UNO. Please see UNOMain.java or http://blueuno.udd.be/ for
// license information. 
// Copyright (C) 2007 Niklas Udd
//
// This class lets a winning user enter name and location in order to report that to the
// high score.

package be.udd.blueuno;

import javax.microedition.lcdui.*;

public class SendScreen implements IUNOState, CommandListener {
	private UNOMain controller;
	private Language language;

	private Form form;
	private TextField nameField;
	private TextField locationField;
	private Command exitCommand;
	private Command sendCommand;

	private ScoreReporter reporter;
	private boolean extraMessageShown;
	private int points;

	public SendScreen(UNOMain controller, Language language, int points) {
		this.controller = controller;
		this.language = language;
		this.points = points;
		reporter = new ScoreReporter(this);
		extraMessageShown = false;

		nameField = new TextField(language.get("name"), controller.getName(), 30, TextField.ANY);
		locationField = new TextField(language.get("location"), null, 30, TextField.ANY);

		sendCommand = new Command(language.get("send"), Command.OK, 1);
		exitCommand = new Command(language.get("exit"), Command.EXIT, 2);

		form = new Form(language.get("send_text"));
		form.append(nameField);
		form.append(locationField);
		form.append(language.get("points") + ": " + points + "\n");
		form.addCommand(sendCommand);
		form.addCommand(exitCommand);
		form.setCommandListener(this);
	}

	public void commandAction(Command c, Displayable d) {
		if (c == sendCommand) {
			send();
		} else if (c == exitCommand) {
			controller.exit();
		}
	}

	private void send() {
		form.removeCommand(sendCommand);
		setExtraMessage(language.get("send_sending"));
		(new Thread() {
			public void run() {
				reporter.send(nameField.getString(), locationField.getString(), points);
			}
		}).start();
	}

	public void sent() {
		form = new Form(language.get("highscore"));
		form.append(language.get("send_success_before") + reporter.getRank() + language.get("send_success_after") + "\n");
		form.append(language.get("highscore") + ":\n");

		String[] highScore = reporter.getHighScore();
		for(int i = 0; i < highScore.length; i++) {
			if(highScore[i] != null)
				form.append((i + 1) + ". " + highScore[i] + "\n");
		}

		form.addCommand(exitCommand);
		form.setCommandListener(this);

		controller.startCurrent();
	}

	public void failed() {
		setExtraMessage(language.get("send_error"));
		form.addCommand(sendCommand);
	}

	private void setExtraMessage(String text) {
		if(extraMessageShown)
			form.delete(form.size() -1 );
		form.append(text);
		extraMessageShown = true;
	}

	public Displayable getDisplayable() {
		return form;
	}
}