// This file is part of Blue UNO. Please see UNOMain.java or http://blueuno.udd.be/ for
// license information. 
// Copyright (C) 2007 Niklas Udd
//
// This class handles the discovery process associated with bluetooth.

package be.udd.blueuno;

import javax.bluetooth.*;
import javax.microedition.io.*;
import java.util.Vector;

public class ServerFinder implements DiscoveryListener {
	private UNOMain controller;
	private ClientStarter starter;
	private Vector remoteDevices;
	private Connecting connecting;
	private ServiceRecord service;

	public ServerFinder(UNOMain controller, ClientStarter starter) {
		this.controller = controller;
		this.starter = starter;
		remoteDevices = new Vector();
		service = null;
	}

	public void findClients() {
		try {
			LocalDevice.getLocalDevice().getDiscoveryAgent().startInquiry(DiscoveryAgent.GIAC, this);
		} catch(Exception e) {
			starter.searchAborted();
		}
	}

	public int numDevicesFound() {
		return remoteDevices.size();
	}

	public String getDeviceName(int pos) {
		RemoteDevice device = (RemoteDevice)remoteDevices.elementAt(pos);
		try {
			return device.getFriendlyName(false);
		} catch(Exception e) {
			return "Unknown device";
		}
	}

	public void select(int pos) {
		int attributes[] = {0x0100};
		UUID[] uuids = {new UUID(Server.UUID,false)}; 

		try {
			LocalDevice.getLocalDevice().getDiscoveryAgent().searchServices(attributes, uuids, (RemoteDevice)remoteDevices.elementAt(pos), this);
		} catch(Exception e) {
			connecting.searchAborted();
		}
	}

	public void setConnecting(Connecting connecting) {
		this.connecting = connecting;
	}

	public void deviceDiscovered(RemoteDevice remoteDevice, DeviceClass deviceClass) {
		remoteDevices.addElement(remoteDevice);
	}

	public void inquiryCompleted(int type) {
		if (remoteDevices.size() > 0)
			controller.selectServer(this);
		else
			starter.noDevicesFound();
	}

	public void servicesDiscovered(int id, ServiceRecord[] services) {
		for(int i = 0; i < services.length; i++) {
			String serviceName = (String)services[i].getAttributeValue(0x0100).getValue();
			if(serviceName.equals("BlueUNO")) {
				service = services[i];
				break;
			}
		}
	}

	public void serviceSearchCompleted(int id, int response) {
		try {
			L2CAPConnection connection = (L2CAPConnection)Connector.open(service.getConnectionURL(ServiceRecord.NOAUTHENTICATE_NOENCRYPT,false));
			BluetoothConnector connector = new BluetoothConnector(connection);
			String status = connector.receiveBlocking();
			if(status.equals("ok")) {
				connector.send(controller.getName());
				connecting.connectorCreated(connector);
			} else if(status.equals("closed")) {
				connecting.serverClosed();
			} else {
				connecting.clientDeprecated();
			}
		} catch(Exception e) {
			connecting.searchAborted();
		}
	}
}