// This file is part of Blue UNO. Please see UNOMain.java or http://blueuno.udd.be/ for
// license information. 
// Copyright (C) 2007 Niklas Udd
//
// This class is reponsible for starting a server.

package be.udd.blueuno;

import javax.microedition.lcdui.*;

public class ServerStarter implements IUNOState, CommandListener {
	private UNOMain controller;
	private Language language;
	private Server server;

	private Form form;
	private Command cancelCommand;
	private Command continueCommand;
	private Command continue2Command;

	private LocalConnector localConnectorClient;
	private LocalConnector localConnectorServer;

	public ServerStarter(UNOMain controller, Language language) {
		this.controller = controller;
		this.language = language;
		server = new Server(controller, this);

		continueCommand = new Command(language.get("continue"), Command.OK, 1);
		continue2Command = new Command(language.get("done"), Command.OK, 1);
		cancelCommand = new Command(language.get("cancel"), Command.CANCEL, 2);
		form = new Form(language.get("server_text"));
		form.append(language.get("server_more1") + "\n");
		form.append(language.get("server_more2") + "\n");
		form.addCommand(continueCommand);
		form.addCommand(cancelCommand);
		form.setCommandListener(this);
	}

	public void commandAction(Command c, Displayable d) {
		if (c == continueCommand) {
			form.removeCommand(continueCommand);
			form.removeCommand(cancelCommand);

			int formSize = form.size();
			form.delete(formSize-1);
			form.delete(formSize-2);

			localConnectorClient = new LocalConnector();
			localConnectorServer = new LocalConnector(localConnectorClient);
			server.addLocalPlayer(localConnectorServer);

			form.append(language.get("server_starting"));
			new Thread(){ public void run() { server.start(); } }.start();
		} else if (c == continue2Command) {
			server.stopAccepting();
			controller.connectionEstablished(localConnectorClient);
			new Thread(){ public void run() { server.startPlaying(); } }.start();
		} else if (c == cancelCommand) {
			controller.cancelServerClient();
		}
	}

	public void serverStarted() {
		form.delete(form.size() - 1);
		form.append(language.get("server_success") + "\n");
		form.addCommand(continue2Command);
	}

	public void serverStartFailed() {
		form.append(language.get("server_error"));
		form.addCommand(cancelCommand);
	}

	public void userConnected(String username) {
		form.append(language.get("server_connected_before") + " \"" + username + "\" " + language.get("server_connected_after"));
	}

	public Displayable getDisplayable() {
		return form;
	}
}