/*
    Blue UNO - a game for playing the card game UNO on bluetooth enabled cell phones.
    Version: 0.2
    Release date: 2007-05-30
    E-mail: blueuno@udd.be
    Web site: http://blueuno.udd.be/
    Copyright (C) 2007 Niklas Udd

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/

package be.udd.blueuno;

import javax.microedition.midlet.*;
import javax.microedition.lcdui.*;

public class UNOMain extends MIDlet {
	private IUNOState currentState;
	private Language language = null;
	private String name;
	private int serverClient;
	private IConnector connector = null;

	public UNOMain() {
		currentState = new LanguageSelector(this);
	}

	public void setLanguage(Language language) {
		this.language = language;
		currentState = new UNOSplash(this, language);
		startCurrent();
	}

	public void languageSelectionFailed() {
		currentState = new LanguageSelectionFailedScreen(this);
		startCurrent();
	}

	public void splashOk() {
		currentState = new NameForm(this, language);
		startCurrent();
	}

	public void setName(String name) {
		this.name = name;
		currentState = new ServerClientSelector(this, language);
		startCurrent();
	}

	public void cancelServerClient() {
		currentState = new ServerClientSelector(this, language);
		startCurrent();
	}		

	public void setServerClient(int serverClient) {
		this.serverClient = serverClient;
		if(serverClient == ServerClientSelector.SERVER)
			currentState = new ServerStarter(this, language);
		else
			currentState = new ClientStarter(this, language);
		startCurrent();
	}

	public void selectServer(ServerFinder serverFinder) {
		currentState = new ServerSelector(this, language, serverFinder);
		startCurrent();
	}

	public void showConnecting(ServerFinder serverFinder) {
		currentState = new Connecting(this, language);
		serverFinder.setConnecting((Connecting)currentState);
		startCurrent();
	}

	public void connectionEstablished(IConnector connector) {
		this.connector = connector;

		currentState = new GameScreen(this, language, connector);
		startCurrent();
	}

	public void gameWon(WonScreen newScreen) {
		currentState = newScreen;
		startCurrent();
	}

	public void gameLost(String winner) {
		currentState = new LostScreen(this, language, winner);
		startCurrent();
	}

	public void sendResult(int points) {
		currentState = new SendScreen(this, language, points);
		startCurrent();
	}

	public void startCurrent() {
		Display.getDisplay(this).setCurrent(currentState.getDisplayable());
	}

	public String getName() {
		return name;
	}

	protected void startApp() {
		startCurrent();
	}

	protected void pauseApp() {}

	protected void destroyApp(boolean unconditional) {}

	public void exit() {
		destroyApp(false);
		notifyDestroyed();
	}
}